@@ -1539,3 +1539,50 @@ CacheDatabase::dbgGetAlwaysFailDialing()
     settings->endGroup ();
     return (rv);
 }//CacheDatabase::dbgGetAlwaysFailDialing
+
+bool
+CacheDatabase::setRefreshSettings (bool enable, quint32 contactsPeriod,
+                                   quint32 inboxPeriod)
+{
+    settings->beginGroup (GV_REFRESH_TABLE);
+    settings->setValue (GV_RP_ENABLED, enable);
+    settings->setValue (GV_RP_CONTACTS, contactsPeriod);
+    settings->setValue (GV_RP_INBOX, inboxPeriod);
+    settings->endGroup ();
+
+    return true;
+}//CacheDatabase::setRefreshSettings
+
+bool
+CacheDatabase::getRefreshSettings (bool &enable, quint32 &contactsPeriod,
+                                   quint32 &inboxPeriod)
+{
+    bool ok;
+
+    settings->beginGroup (GV_REFRESH_TABLE);
+    do  {// Begin cleanup block (not a loop)
+        enable = false;
+        if (settings->contains (GV_RP_ENABLED)) {
+            enable = settings->value (GV_RP_ENABLED).toBool ();
+        }
+
+        ok = false;
+        if (settings->contains (GV_RP_CONTACTS)) {
+            contactsPeriod = settings->value (GV_RP_CONTACTS).toInt (&ok);
+        }
+        if (!ok) {
+            contactsPeriod = 3600;
+        }
+
+        ok = false;
+        if (settings->contains (GV_RP_INBOX)) {
+            inboxPeriod = settings->value (GV_RP_INBOX).toInt (&ok);
+        }
+        if (!ok) {
+            inboxPeriod = 120;
+        }
+    } while (0); // End cleanup block (not a loop)
+    settings->endGroup ();
+
+    return true;
+}//CacheDatabase::getRefreshSettings
