@@ -59,6 +59,8 @@ MainWindow::MainWindow (QWidget *parent)
             .toLatin1().constData (), this)
 #endif
 , bQuitPath (false)
+, contactsTimer (this)
+, inboxTimer (this)
 {
     modelRegNumber = new RegNumberModel(this);
     if (modelRegNumber == NULL) {
@@ -115,6 +117,15 @@ MainWindow::MainWindow (QWidget *parent)
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
+    rv = connect (&contactsTimer, SIGNAL(timeout()),
+                  this, SLOT(onPeriodicContactsRefresh()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (&inboxTimer, SIGNAL(timeout()),
+                  this, SLOT(onPeriodicInboxRefresh()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
     // Schedule the init a bit later so that the app.exec() can begin executing
     QTimer::singleShot (10, this, SLOT (init()));
 }//MainWindow::MainWindow
@@ -172,10 +183,10 @@ void
 MainWindow::messageReceived (const QString &message)
 {
     if (message == "show") {
-        qDebug ("Second instance asked us to show");
+        Q_DEBUG ("Second instance asked us to show");
         this->show ();
     } else if (message == "quit") {
-        qDebug ("Second instance asked us to quit");
+        Q_DEBUG ("Second instance asked us to quit");
         this->on_actionE_xit_triggered ();
     }
 }//MainWindow::messageReceived
@@ -689,6 +700,21 @@ MainWindow::connectSettingsSignals()
                       this, SLOT   (doLogout ()));
         Q_ASSERT(rv);
         if (!rv) { break; }
+
+        obj = getQMLObject ("RefreshSettingsPage");
+        if (obj == NULL) {
+            Q_WARN("Could not find RefreshSettingsPage");
+            break;
+        }
+        rv = connect(obj, SIGNAL(sigRefreshChanges(bool,const QString&,const QString&,bool,const QString&,int,const QString&)),
+                     this,SLOT(onSigRefreshChanges(bool,const QString&,const QString&,bool,const QString&,int,const QString&)));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
+
+        rv = connect (obj , SIGNAL (sigRefreshPeriodSettings()),
+                      this, SLOT   (refreshPeriodSettings()));
+        Q_ASSERT(rv);
+        if (!rv) { break; }
     } while (0); // End cleanup block (not a loop)
 
     return (rv);
@@ -721,7 +747,7 @@ MainWindow::on_actionE_xit_triggered ()
                                          i != mapVmail.end ();
                                          i++)
     {
-        qDebug() << "Delete vmail cached at" << i.value ();
+        Q_DEBUG(QString("Delete vmail cached at %1").arg (i.value ()));
         QFile::remove (i.value ());
     }
     mapVmail.clear ();
@@ -948,7 +974,7 @@ MainWindow::onSigProxyRefresh(bool bSet)
 void
 MainWindow::onLinkActivated (const QString &strLink)
 {
-    qDebug() << "MainWindow: Link activated" << strLink;
+    Q_DEBUG(QString("MainWindow: Link activated: %1").arg (strLink));
     QDesktopServices::openUrl (QUrl::fromUserInput (strLink));
 }//MainWindow::onLinkActivated
 
@@ -987,9 +1013,9 @@ MainWindow::refreshMqSettings (bool bForceShut /*= false*/)
     }
 
     do { // Begin cleanup block (not a loop)
-        QObject *pMqSettings = getQMLObject ("MosquittoPage");
-        if (NULL == pMqSettings) {
-            Q_WARN("Could not get to MosquittoPage");
+        QObject *obj = getQMLObject ("RefreshSettingsPage");
+        if (NULL == obj) {
+            Q_WARN("Could not get to RefreshSettingsPage");
             break;
         }
 
@@ -1007,7 +1033,7 @@ MainWindow::refreshMqSettings (bool bForceShut /*= false*/)
             strTopic = "gv_notify";
         }
 
-        QMetaObject::invokeMethod (pMqSettings, "setValues",
+        QMetaObject::invokeMethod (obj, "setMqValues",
                                    Q_ARG (QVariant, QVariant(bEnable)),
                                    Q_ARG (QVariant, QVariant(strHost)),
                                    Q_ARG (QVariant, QVariant(port)),
@@ -1019,26 +1045,30 @@ MainWindow::refreshMqSettings (bool bForceShut /*= false*/)
 void
 MainWindow::initMq()
 {
-    bool bEnable = false;
+    bool bEnable = false, bRefreshEnable, ok;
     QString host, topic;
     int port;
-
+    quint32 contactsSec, inboxSec;
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
-    if (!dbMain.getMqSettings (bEnable, host, port, topic)) {
-        return;
-    }
 
-    refreshMqSettings ();
-
-    qDebug() << "Initially Mq is" << (bEnable ? "enabled" : "disabled");
+    refreshPeriodSettings ();
 
+    ok = dbMain.getMqSettings (bEnable, host, port, topic);
 #if MOSQUITTO_CAPABLE
-    if (bEnable) {
-        qDebug ("Start Mq thread.");
+    Q_DEBUG(QString("Initially Mq is %1").arg(bEnable ? "enabled":"disabled"));
+    if (ok && bEnable) {
+        Q_DEBUG ("Start Mq thread.");
         mqThread.setSettings (bEnable, host, port);
         mqThread.start();
     }
 #endif
+
+    ok = dbMain.getRefreshSettings (bRefreshEnable, contactsSec, inboxSec);
+    Q_ASSERT(contactsTimer.isActive() == inboxTimer.isActive());
+    if (ok && bRefreshEnable && !contactsTimer.isActive()) {
+        contactsTimer.start (contactsSec);
+        inboxTimer.start (inboxSec);
+    }
 }//MainWindow::initMq
 
 void
@@ -1423,3 +1453,88 @@ MainWindow::onUserAllowedDelete(bool ok)
    delete id;
 }//MainWindow::onUserAllowedDelete
 
+void
+MainWindow::onSigRefreshChanges(bool bRefreshEnable,
+                                const QString &contactsPeriod,
+                                const QString &inboxPeriod, bool bMqEnable,
+                                const QString &host, int port,
+                                const QString &topic)
+{
+    quint32 contactsSec = contactsPeriod.toInt ();
+    quint32 inboxSec = inboxPeriod.toInt ();
+
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    dbMain.setRefreshSettings (bRefreshEnable, contactsSec, inboxSec);
+
+    Q_ASSERT(contactsTimer.isActive() == inboxTimer.isActive());
+
+    if (bRefreshEnable && !contactsTimer.isActive()) {
+        contactsTimer.start (contactsSec);
+        inboxTimer.start (inboxSec);
+    }
+
+    onSigMosquittoChanges (bMqEnable, host, port, topic);
+}//MainWindow::onSigRefreshChanges
+
+void
+MainWindow::refreshPeriodSettings(bool bForceShut /*= false*/)
+{
+    refreshMqSettings (bForceShut);
+
+    bool bEnable = bForceShut;
+    quint32 contactsPeriod, inboxPeriod;
+
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    if (!dbMain.getRefreshSettings (bEnable, contactsPeriod, inboxPeriod)) {
+        return;
+    }
+
+    if (bForceShut) {
+        bEnable = false;
+    }
+
+    do { // Begin cleanup block (not a loop)
+        QObject *obj = getQMLObject ("RefreshSettingsPage");
+        if (NULL == obj) {
+            Q_WARN("Could not get to RefreshSettingsPage");
+            break;
+        }
+
+        QMetaObject::invokeMethod (obj, "setRefreshValues",
+                                   Q_ARG (QVariant, QVariant(bEnable)),
+                                   Q_ARG (QVariant, QVariant(contactsPeriod)),
+                                   Q_ARG (QVariant, QVariant(inboxPeriod)));
+    } while (0); // End cleanup block (not a loop)
+}//MainWindow::refreshPeriodSettings
+
+void
+MainWindow::onPeriodicContactsRefresh()
+{
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    bool bEnable;
+    quint32 contactsPeriod, inboxPeriod;
+
+    oContacts->refreshContacts ();
+
+    if (!dbMain.getRefreshSettings (bEnable, contactsPeriod, inboxPeriod)) {
+        return;
+    }
+
+    contactsTimer.start (contactsPeriod);
+}//MainWindow::onPeriodicContactsRefresh
+
+void
+MainWindow::onPeriodicInboxRefresh()
+{
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    bool bEnable;
+    quint32 contactsPeriod, inboxPeriod;
+
+    oInbox->checkRecent ();
+
+    if (!dbMain.getRefreshSettings (bEnable, contactsPeriod, inboxPeriod)) {
+        return;
+    }
+
+    inboxTimer.start (inboxPeriod);
+}//MainWindow::onPeriodicInboxRefresh
